@@ -24,7 +24,7 @@ class MiniECS:
     def __init__(self, address = 'localhost', port = 65535) -> None:
         self.address = address
         self.port = port
-        self.sock = socket.create_connection((address, port))
+        self.sock = None
         self.containers_list = []
 
     def create_container(self, name: str):
@@ -37,7 +37,7 @@ class MiniECS:
 
             try:
                 # Send data
-                self.sock.listen()
+                self.sock = socket.create_connection((self.address, self.port))
                 message = str.encode(name)
                 print('sending {!r}'.format(message))
                 self.sock.sendall(message)
